Learn R Programming

matriz (version 1.0.1)

matriz_names: Retrieve Column Classes from deafult literature matrix.

Description

This function calls init_matrix() to obtain a matrix or data frame, then extracts the class of each column. It returns a data frame containing the class information for each column.

Usage

matriz_names(...)

Value

A data frame with one column named class that lists the class of each column from the matrix or data frame returned by init_matrix().

Arguments

...

extra arguments to pass as column names for the literature matrix

Details

The purpose of this function is to provide the user with a quick way to check the default names and classes as the matrix is being filled instead of having to type `str(init_matrix())` every time the user forgets a category in the default matrix.

Examples

Run this code
matriz_names()


Run the code above in your browser using DataLab